# Generated by Django 2.1.5 on 2019-04-04 21:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tenant_only', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UploadFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('filename', models.FileField(upload_to='uploads/')),
            ],
        ),
    ]
