<!DOCTYPE html>
<html lang="en">
<!--Html file used to test template loaders and template caching-->
<head>
    <meta charset="UTF-8">
    <title>This is the template for tenant 'test'.</title>
</head>
<body>

</body>
</html>
