# Generated by Django 3.1 on 2020-11-24 16:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0003_auto_20190404_1612'),
    ]

    operations = [
        migrations.AddField(
            model_name='client',
            name='type',
            field=models.CharField(choices=[('public', 'public'), ('type1', 'type1'), ('type2', 'type2')], default='type1', max_length=100),
            preserve_default=False,
        ),
    ]
